@@ -10,11 +10,11 @@ class Jiffy:
     def __init__(self, config):
         self._config = config
 
-    def run(self):
+    def run(self, dry_run=False):
         delete_local_repo(self._config)
         download_to_local(self._config)
-        all_tasks = get_tasks(self._config)
+        all_tasks = get_tasks(request=self._config)
         for task_name in all_tasks['task_order']:
-            all_tasks['tasks'][task_name].run()
+            all_tasks['tasks'][task_name].run(dry_run=dry_run)
         delete_local_repo(self._config)
         return True
