@@ -16,11 +16,37 @@ class SQLTask(BaseSQLTask):
         self._get_output_table_name()
         self._get_validation_tasks()
 
-    def run(self):
+    def run(self, dry_run=False):
+        """
+        Run SQL script to create a table if needed. If dry run, just run anyway.
+
+        :return: None
+        """
+        if dry_run:
+            run_script(query_data=self._query_data,
+                       dry_run=dry_run)
+        else:
+            if self._table_has_not_been_run():
+                run_script(self._query_data)
+            self._run_tests_for_output_table()
+
+    def _table_has_not_been_run(self):
+        """
+        If table passes all the validation tests then it does not need to be run.
+
+        :return: True = table has not been run / False = table has been run
+        """
         for validation_task in self._validation_tasks:
             if not validation_task.run_test():
-                run_script(self._query_data)
-                break
+                return True
+        return False
+
+    def _run_tests_for_output_table(self):
+        """
+        Run all validation tests and write the output to the validation table. Raise an error if any tests fail.
+
+        :return: None
+        """
         test_results = []
         for validation_task in self._validation_tasks:
             test_results.append(validation_task.run_test())
@@ -31,6 +57,14 @@ class SQLTask(BaseSQLTask):
                                f'Request that caused the failure: {self._request}')
 
     def get_dependencies(self):
+        """
+        Search through the SQL script for all BigQuery table references.
+
+        Store those dependencies in a dict along with the output table name.
+
+        :return: Dependencies of required tables and output table name
+        """
+
         tables = table_regex.findall(self._query_data['sql'])
         dependencies = {
             'output_table': self.output_table_name,
@@ -39,6 +73,14 @@ class SQLTask(BaseSQLTask):
         return dependencies
 
     def _get_output_table_name(self):
+        """
+        Build the fully qualified name of the BigQuery table that this task will create / write to.
+
+        E.g.: cool-project.funky_dataset.300_solid_data
+
+        :return: Full table name
+        """
+
         table = file_name_regex.findall(self._filename)[0]
         dataset = self._params['dataset']
         project = self._request['project']
@@ -47,6 +89,12 @@ class SQLTask(BaseSQLTask):
         return self.output_table_name
 
     def _get_validation_tasks(self):
+        """
+        Gather all of the validation tasks required for this table.
+
+        :return: List of validation tasks
+        """
+
         js = self._query_data['job_settings'].get('VALIDATION', None)
         if js:
             for validation_name in js.split(','):
